==> openapi_jira_client-3.0.0-py3-none-any.whl: openapi_jira_client/api/filters/update_filter.py <==
from typing import Any, Dict, List, Optional, Union, cast

import httpx
from attr import asdict

from ...client import AuthenticatedClient, Client
from ...models.filter import Filter
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    id: int,
    json_body: Filter,
    expand: Union[Unset, str] = UNSET,
) -> Dict[str, Any]:
    url = "{}/rest/api/3/filter/{id}".format(client.base_url, id=id)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {
        "expand": expand,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    json_json_body = json_body.to_dict()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
        "params": params,
    }


def _parse_response(*, response: httpx.Response) -> Optional[Union[Filter, None, None]]:
    if response.status_code == 200:
        response_200 = Filter.from_dict(response.json())

        return response_200
    if response.status_code == 400:
        response_400 = None

        return response_400
    if response.status_code == 401:
        response_401 = None

        return response_401
    return None


def _build_response(*, response: httpx.Response) -> Response[Union[Filter, None, None]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    id: int,
    json_body: Filter,
    expand: Union[Unset, str] = UNSET,
) -> Response[Union[Filter, None, None]]:
    kwargs = _get_kwargs(
        client=client,
        id=id,
        json_body=json_body,
        expand=expand,
    )

    response = httpx.put(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    id: int,
    json_body: Filter,
    expand: Union[Unset, str] = UNSET,
) -> Optional[Union[Filter, None, None]]:
    """Updates a filter. Use this operation to update a filter's name, description, JQL, or sharing.

    **[Permissions](#permissions) required:** Permission to access Jira, however the user must own the filter."""

    return sync_detailed(
        client=client,
        id=id,
        json_body=json_body,
        expand=expand,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    id: int,
    json_body: Filter,
    expand: Union[Unset, str] = UNSET,
) -> Response[Union[Filter, None, None]]:
    kwargs = _get_kwargs(
        client=client,
        id=id,
        json_body=json_body,
        expand=expand,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.put(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    id: int,
    json_body: Filter,
    expand: Union[Unset, str] = UNSET,
) -> Optional[Union[Filter, None, None]]:
    """Updates a filter. Use this operation to update a filter's name, description, JQL, or sharing.

    **[Permissions](#permissions) required:** Permission to access Jira, however the user must own the filter."""

    return (
        await asyncio_detailed(
            client=client,
            id=id,
            json_body=json_body,
            expand=expand,
        )
    ).parsed

==> openapi_jira_client-3.0.1-py3-none-any.whl: openapi_jira_client/api/filters/update_filter.py <==
from typing import Any, Dict, List, Optional, Union, cast

import httpx
from attr import asdict

from ...client import AuthenticatedClient, Client
from ...models.filter import Filter
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    id_: int,
    json_body: Filter,
    expand: Union[Unset, str] = UNSET,
) -> Dict[str, Any]:
    url = "{}/rest/api/3/filter/{id}".format(client.base_url, id=id_)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {
        "expand": expand,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    json_json_body = json_body.to_dict()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
        "params": params,
    }


def _parse_response(*, response: httpx.Response) -> Optional[Union[Filter, None, None]]:
    if response.status_code == 200:
        response_200 = Filter.from_dict(response.json())

        return response_200
    if response.status_code == 400:
        response_400 = None

        return response_400
    if response.status_code == 401:
        response_401 = None

        return response_401
    return None


def _build_response(*, response: httpx.Response) -> Response[Union[Filter, None, None]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    id_: int,
    json_body: Filter,
    expand: Union[Unset, str] = UNSET,
) -> Response[Union[Filter, None, None]]:
    kwargs = _get_kwargs(
        client=client,
        id_=id_,
        json_body=json_body,
        expand=expand,
    )

    response = httpx.put(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    id_: int,
    json_body: Filter,
    expand: Union[Unset, str] = UNSET,
) -> Optional[Union[Filter, None, None]]:
    """Updates a filter. Use this operation to update a filter's name, description, JQL, or sharing.

    **[Permissions](#permissions) required:** Permission to access Jira, however the user must own the filter."""

    return sync_detailed(
        client=client,
        id_=id_,
        json_body=json_body,
        expand=expand,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    id_: int,
    json_body: Filter,
    expand: Union[Unset, str] = UNSET,
) -> Response[Union[Filter, None, None]]:
    kwargs = _get_kwargs(
        client=client,
        id_=id_,
        json_body=json_body,
        expand=expand,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.put(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    id_: int,
    json_body: Filter,
    expand: Union[Unset, str] = UNSET,
) -> Optional[Union[Filter, None, None]]:
    """Updates a filter. Use this operation to update a filter's name, description, JQL, or sharing.

    **[Permissions](#permissions) required:** Permission to access Jira, however the user must own the filter."""

    return (
        await asyncio_detailed(
            client=client,
            id_=id_,
            json_body=json_body,
            expand=expand,
        )
    ).parsed
